The Technique for Order of Preference by Similarity to Ideal Solution (TOPSIS) is a multi-criteria decision analysis method. TOPSIS is based on the concept that the chosen alternative should have the shortest geometric distance from the positive ideal solution (PIS) and the longest geometric distance from the negative ideal solution (NIS). 
This package will helps you in TOPSIS analysis of csv files.
Please make sure that your dataset doesn't contain categorical data.
Source:
https://en.wikipedia.org/wiki/TOPSIS